/* Includes ------------------------------------------------------------------*/
#include "main.h"
#include "HW_Configs.h"

//   ------------------------------------------------------

//    ----------------------------------------

/////////////  ,    /////////////////////////
void SYS_Config(void)
{
	//    -----------------------------------------------------
#ifdef NODEBUG
	if (FLASH_OB_GetRDP() == RESET) //     
	{
		FLASH_OB_Unlock(); //  
		FLASH_OB_RDPConfig(OB_RDP_Level_1);
		FLASH_OB_Lock(); //  
	}
#endif  

	//   -----------------------------------------------------------
#ifdef W_DOG
	IWDG_WriteAccessCmd(IWDG_WriteAccess_Enable); //     
	IWDG_SetPrescaler(IWDG_Prescaler_16); // 40 / 16 = 400 -  
	IWDG_SetReload(2500); // 0.4 * 2500 = 1  -  
	while(IWDG_GetFlagStatus(IWDG_FLAG_RVU) != RESET) {} //  
	IWDG_ReloadCounter(); //  
	IWDG_Enable(); //     LSI
#endif  
}


/////////////   /////////////////////////////////////////////
void SCK_Config(void)
{
	//  ----------------------------------------------------------------------
	RCC_DeInit(); //   " "
	RCC_HCLKConfig(RCC_SYSCLK_Div1); //   AHB
	RCC_PCLKConfig(RCC_HCLK_Div1); //    APB

#ifdef EXT_QUARZ //  
	RCC_HSEConfig(RCC_HSE_ON); //   
	if (RCC_WaitForHSEStartUp() == ERROR) //   
	{ //   -    
		RCC_HSEConfig(RCC_HSE_OFF); //   
		Delay_ms(120);
		NVIC_SystemReset();
	}
	else // 
	{
		RCC_ClockSecuritySystemCmd(ENABLE); //  CSS (  NMI)
		RCC_PREDIV1Config(RCC_PREDIV1_Div2); // 8MHz /2 (  /2  HSI)
		RCC_PLLConfig(RCC_PLLSource_PREDIV1, RCC_PLLMul_12); // PLLCLK = 8MHz /2 * 12 = 48 MHz
	}
#else //  
	RCC_PLLConfig(RCC_PLLSource_HSI_Div2, RCC_PLLMul_12); // PLLCLK = 8MHz /2 * 12 = 48 MHz
#endif

	RCC_PLLCmd(ENABLE); //  PLL
	while (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET) {} //   PLL
	RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK); //  SYSCLK  PLL
	while (RCC_GetSYSCLKSource() != 0x08) {} //     PLL
	// --------------------------------------------------------------------------
	SystemCoreClockUpdate (); //  SystemCoreClock =  
}


///////////// Configures GPIO //////////////////////////////////////////
void GPIO_Config(void)
{
	GPIO_InitTypeDef GPIO_InitStructure; //    

	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOA, ENABLE); //     AHB
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOB, ENABLE); //     AHB
	RCC_AHBPeriphClockCmd(RCC_AHBPeriph_GPIOF, ENABLE); //     AHB

	GPIO_DeInit(GPIOA); //   " "
	GPIO_DeInit(GPIOB); //   " "
	GPIO_DeInit(GPIOF); //   " "

	// SPI1
	GPIO_PinAFConfig(GPIOB, GPIO_PinSource3, GPIO_AF_0); //  
	GPIO_PinAFConfig(GPIOB, GPIO_PinSource4, GPIO_AF_0); //  
	GPIO_PinAFConfig(GPIOB, GPIO_PinSource5, GPIO_AF_0); //  
	GPIO_PinAFConfig(GPIOA, GPIO_PinSource15, GPIO_AF_0); //  
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_3|GPIO_Pin_4|GPIO_Pin_5; //   
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF; // 		
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz; // 
	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP; //   
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL; // 
	GPIO_Init(GPIOB, &GPIO_InitStructure); 
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15; //   
	GPIO_Init(GPIOA, &GPIO_InitStructure); // 

	// --> DAC
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4; //   
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AN; // 
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL; // 
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz; // 
	GPIO_Init(GPIOA, &GPIO_InitStructure); // 

	// --> 
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_2|GPIO_Pin_3|GPIO_Pin_5|GPIO_Pin_6|GPIO_Pin_7|GPIO_Pin_8|GPIO_Pin_9|GPIO_Pin_10|GPIO_Pin_11|GPIO_Pin_12; //   
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT; // 
	GPIO_InitStructure.GPIO_OType = GPIO_OType_PP; //   
	GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL; // 
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz; // 
	GPIO_Init(GPIOA, &GPIO_InitStructure); // 
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0|GPIO_Pin_1|GPIO_Pin_6|GPIO_Pin_7; //   
	GPIO_Init(GPIOB, &GPIO_InitStructure); // 
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_0|GPIO_Pin_1; //   
	GPIO_Init(GPIOF, &GPIO_InitStructure); // 
}


/////////////   /////////////////////
void DAC_Config(void)
{
	DAC_InitTypeDef DAC_InitStructure;

	DAC_DeInit(); //  
	RCC_APB1PeriphClockCmd(RCC_APB1Periph_DAC, ENABLE);

	DAC_InitStructure.DAC_Trigger = DAC_Trigger_None;
	DAC_InitStructure.DAC_WaveGeneration = DAC_WaveGeneration_None;
	DAC_InitStructure.DAC_OutputBuffer = DAC_OutputBuffer_Enable; // 
	DAC_InitStructure.DAC_LFSRUnmask_TriangleAmplitude = DAC_TriangleAmplitude_15;
	DAC_Init(DAC_Channel_1, &DAC_InitStructure);

	DAC_DMACmd(DAC_Channel_1, ENABLE);
	DAC_Cmd(DAC_Channel_1, ENABLE);
}


///////////////////////////// Configures SPI ///////////////////////////////////////////
void SPI_Config(void)
{
	SPI_InitTypeDef SPI_InitStructure;

	RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1, ENABLE); // 
   
	SPI_I2S_DeInit(SPI1); //   " "

	SPI_StructInit(&SPI_InitStructure);
	SPI_InitStructure.SPI_Direction = SPI_Direction_1Line_Rx;
	SPI_InitStructure.SPI_Mode = SPI_Mode_Slave; // 
	SPI_InitStructure.SPI_DataSize = SPI_DataSize_10b;
	SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low; //   
	SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge; //   
	SPI_InitStructure.SPI_NSS = SPI_NSS_Hard; //    - ( SSM)
	SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_8; // 6MHz
	SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB; //   - 
	SPI_InitStructure.SPI_CRCPolynomial = 7;
	SPI_Init(SPI1, &SPI_InitStructure);

//	SPI_NSSPulseModeCmd(SPI1, ENABLE); //  ( NSSP)     
//	SPI_SSOutputCmd(SPI1, ENABLE); // ( SSOE) NSS  (  )

	SPI_Cmd(SPI1, ENABLE); // 
}


// -------------------------------------------------------------------------------------------------------



